"""
Created on 30.04.2021
This script can save email attachments into one specific directory and rename the file.
@author: baier
"""

import os
from exchangelib import Message, FileAttachment, ItemAttachment


# Read & Save Attachments code
def save_attachment(exchange_folder_name: str, save_to_folder: str, account_var, suffix=0,
                    prename='', last_items=1) -> str:
    folder = account_var.inbox / exchange_folder_name
    for item in folder.all().order_by('-datetime_received')[:last_items]:
        for attachment in item.attachments:
            print('Number of Attachment found:', len(item.attachments))
            if isinstance(attachment, FileAttachment):
                local_path = os.path.join(save_to_folder, prename + attachment.name[suffix:])
                with open(local_path, 'wb') as f:
                    f.write(attachment.content)
                print('Saved attachment to', local_path)
                return local_path
            elif isinstance(attachment, ItemAttachment):
                if isinstance(attachment.item, Message):
                    print(attachment.item.subject, attachment.item.body)



"""
Created on 20.04.2021

@author: baier
"""

import os
import pandas as pd

from accessOutlookEmail import save_attachment, create_account

account = create_account('kreutmair@orcacapital.de', 'ubeRr@schun9')


def editSaveMorrison(rename_file: str, load_from_folder: str, save_to_folder: str):
    # open Excel
    os.chdir(load_from_folder)
    df = pd.read_excel(save_attachment('Morrison', load_from_folder, account))
    z_au_leihe = pd.read_excel(save_to_folder + r'\Z_AU_Leihe.xlsx')

    # edit the file
    df.columns = [c.replace(' ', '_') for c in df.columns]
    ticker = df.Security
    qty = df.Qty_LOCATED
    rows = df[df.columns[0]].count()
    
    z_au_leihe_col_a = z_au_leihe['Security']
    z_au_leihe_col_d = z_au_leihe['Qty LOCATED']
    
    for i in range(rows):
        z_au_leihe_col_a.loc[i] = ticker.iloc[i][0:3]
        z_au_leihe_col_d.loc[i] = qty.iloc[i]

    # save Excel
    os.chdir(save_to_folder)
    z_au_leihe.to_excel(rename_file, index=False)


editSaveMorrison(r'testFile.xlsx', r'C:\Users\baier\Downloads', r'O:\Listenpflege\AU_Leihe_Option')



"""
Created on 10.05.2021

@author: baier
"""
from accessOutlookEmail import create_account, save_attachment

account = create_account('kreutmair@orcacapital.de', 'ubeRr@schun9')

save_attachment('Steubing', r'W:\01. ORCA Depot\Z InputConfirms\Steubing', account)
